purdy
*****

During talks or screencasts I don't want to be typing code, it is too error
prone and too likely to mess up my speaking flow. "purdy" takes snippets of
code and displays them to a terminal using Pygments colourization. It listens
for input and shows a line as if it is being typed each time you press enter.

Installation
============

.. code-block:: bash

    $ pip install purdy

Supports
========

purdy has been tested with Python 3.7

Docs & Source
=============

Docs: http://purdy.readthedocs.io/en/latest/

Source: https://github.com/cltrudeau/purdy
